Django Categories v 1.1 — Django Categories v1.1 documentation

Django Categories v1.1 documentation

# Django Categories v 1.1

- Table of Contents
- index
  next

# Django Categories v 1.1

Django Categories grew out of our need to provide a basic hierarchical taxonomy management system that multiple applications could use independently or in concert.

As a news site, our stories, photos, and other content get divided into “sections” and we wanted all the apps to use the same set of sections. As our needs grew, the Django Categories grew in the functionality it gave to category handling within web pages.

## New in 1.1

- Fixed a cosmetic bug in the Django 1.4 admin. Action checkboxes now only appear once.
- Template tags are refactored to allow easy use of any model derived from `CategoryBase`.
- Improved test suite.
- Improved some of the documentation.

## Contents

- Installation
  - To use the Category model
  - To only subclass CategoryBase
- Getting Started
  - Connecting your model with Django-Categories
- Using categories in templates
  - Getting all items within a category
  - Template Tags
- Registering Models
  - Registering models in settings.py
  - Registering a many-to-one relationship
  - Registering a many-to-many relationship
- Adding the fields to the database
  - Enter South
  - Reconfiguring Fields
- Creating Custom Categories
  - Name only
  - Name and other data
- Reference
  - Management Commands
  - Models
  - Settings
  - Template tags and filters

## Indices and tables

- Index
- Module Index
- Search Page